
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5ServiceFramework_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

set(Qt5ServiceFramework_VERSION_MAJOR 0)
set(Qt5ServiceFramework_VERSION_MINOR 0)
set(Qt5ServiceFramework_VERSION_PATCH 0)
set(Qt5ServiceFramework_VERSION_STRING 0.0.0)

set(Qt5ServiceFramework_LIBRARIES Qt5::ServiceFramework)

macro(_populate_ServiceFramework_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::ServiceFramework APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::ServiceFramework PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5ServiceFramework_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "${_qt5ServiceFramework_install_prefix}/lib/${LIB_LOCATION}"
    )
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(Qt5::ServiceFramework PROPERTIES
            "IMPORTED_IMPLIB_${Configuration}" "${_qt5ServiceFramework_install_prefix}/lib/${IMPLIB_LOCATION}"
        )
    endif()
endmacro()

if (NOT TARGET Qt5::ServiceFramework)

    set(Qt5ServiceFramework_INCLUDE_DIRS "${_qt5ServiceFramework_install_prefix}/include/qt5/QtServiceFramework")
    set(Qt5ServiceFramework_PRIVATE_INCLUDE_DIRS
        "${_qt5ServiceFramework_install_prefix}/include/qt5/QtServiceFramework/${Qt5ServiceFramework_VERSION_STRING}"
        "${_qt5ServiceFramework_install_prefix}/include/qt5/QtServiceFramework/${Qt5ServiceFramework_VERSION_STRING}/QtServiceFramework"
    )

    set(Qt5ServiceFramework_DEFINITIONS -DQT_SERVICEFRAMEWORK_LIB)
    set(Qt5ServiceFramework_COMPILE_DEFINITIONS QT_SERVICEFRAMEWORK_LIB)

    set(_Qt5ServiceFramework_MODULE_DEPENDENCIES "Core")

    set(_Qt5ServiceFramework_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5ServiceFramework_FIND_REQUIRED)
        set(_Qt5ServiceFramework_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5ServiceFramework_FIND_DEPENDENCIES_QUIET)
    if (Qt5ServiceFramework_FIND_QUIETLY)
        set(_Qt5ServiceFramework_DEPENDENCIES_FIND_QUIET QUIET)
    endif()

    foreach(_module_dep ${_Qt5ServiceFramework_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                ${_Qt5ServiceFramework_DEPENDENCIES_FIND_QUIET}
                ${_Qt5ServiceFramework_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${_qt5ServiceFramework_install_prefix}" NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5ServiceFramework_FOUND False)
            return()
        endif()

        list(APPEND Qt5ServiceFramework_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5ServiceFramework_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5ServiceFramework_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5ServiceFramework_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5ServiceFramework_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5ServiceFramework_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5ServiceFramework_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5ServiceFramework_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5ServiceFramework_COMPILE_DEFINITIONS)
    if (Qt5ServiceFramework_EXECUTABLE_COMPILE_FLAGS)
      list(REMOVE_DUPLICATES Qt5ServiceFramework_EXECUTABLE_COMPILE_FLAGS)
    endif()

    set(_Qt5ServiceFramework_LIB_DEPENDENCIES "Qt5::Core")

    add_library(Qt5::ServiceFramework SHARED IMPORTED)

    _populate_ServiceFramework_target_properties(RELEASE "Qt0ServiceFramework.dll" "Qt0ServiceFramework.lib" )

    if (EXISTS "${_qt5ServiceFramework_install_prefix}/lib/Qt0ServiceFrameworkd.dll" AND EXISTS "${_qt5ServiceFramework_install_prefix}/lib/Qt0ServiceFrameworkd.lib" )
        _populate_ServiceFramework_target_properties(DEBUG "Qt0ServiceFrameworkd.dll" "Qt0ServiceFrameworkd.lib" )
    endif()





endif()
