
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5SystemInfo_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

set(Qt5SystemInfo_VERSION_MAJOR 0)
set(Qt5SystemInfo_VERSION_MINOR 0)
set(Qt5SystemInfo_VERSION_PATCH 0)
set(Qt5SystemInfo_VERSION_STRING 0.0.0)

set(Qt5SystemInfo_LIBRARIES Qt5::SystemInfo)

macro(_populate_SystemInfo_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::SystemInfo APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::SystemInfo PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5SystemInfo_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "${_qt5SystemInfo_install_prefix}/lib/${LIB_LOCATION}"
    )
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(Qt5::SystemInfo PROPERTIES
            "IMPORTED_IMPLIB_${Configuration}" "${_qt5SystemInfo_install_prefix}/lib/${IMPLIB_LOCATION}"
        )
    endif()
endmacro()

if (NOT TARGET Qt5::SystemInfo)

    set(Qt5SystemInfo_INCLUDE_DIRS "${_qt5SystemInfo_install_prefix}/include/qt5/QtSystemInfo")
    set(Qt5SystemInfo_PRIVATE_INCLUDE_DIRS
        "${_qt5SystemInfo_install_prefix}/include/qt5/QtSystemInfo/${Qt5SystemInfo_VERSION_STRING}"
        "${_qt5SystemInfo_install_prefix}/include/qt5/QtSystemInfo/${Qt5SystemInfo_VERSION_STRING}/QtSystemInfo"
    )

    set(Qt5SystemInfo_DEFINITIONS -DQT_SYSTEMINFO_LIB)
    set(Qt5SystemInfo_COMPILE_DEFINITIONS QT_SYSTEMINFO_LIB)

    set(_Qt5SystemInfo_MODULE_DEPENDENCIES "Gui;Network;Core")

    set(_Qt5SystemInfo_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5SystemInfo_FIND_REQUIRED)
        set(_Qt5SystemInfo_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5SystemInfo_FIND_DEPENDENCIES_QUIET)
    if (Qt5SystemInfo_FIND_QUIETLY)
        set(_Qt5SystemInfo_DEPENDENCIES_FIND_QUIET QUIET)
    endif()

    foreach(_module_dep ${_Qt5SystemInfo_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                ${_Qt5SystemInfo_DEPENDENCIES_FIND_QUIET}
                ${_Qt5SystemInfo_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${_qt5SystemInfo_install_prefix}" NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5SystemInfo_FOUND False)
            return()
        endif()

        list(APPEND Qt5SystemInfo_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5SystemInfo_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5SystemInfo_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5SystemInfo_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5SystemInfo_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5SystemInfo_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5SystemInfo_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5SystemInfo_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5SystemInfo_COMPILE_DEFINITIONS)
    if (Qt5SystemInfo_EXECUTABLE_COMPILE_FLAGS)
      list(REMOVE_DUPLICATES Qt5SystemInfo_EXECUTABLE_COMPILE_FLAGS)
    endif()

    set(_Qt5SystemInfo_LIB_DEPENDENCIES "Qt5::Gui;Qt5::Network;Qt5::Core")

    add_library(Qt5::SystemInfo SHARED IMPORTED)

    _populate_SystemInfo_target_properties(RELEASE "Qt0SystemInfo.dll" "Qt0SystemInfo.lib" )

    if (EXISTS "${_qt5SystemInfo_install_prefix}/lib/Qt0SystemInfod.dll" AND EXISTS "${_qt5SystemInfo_install_prefix}/lib/Qt0SystemInfod.lib" )
        _populate_SystemInfo_target_properties(DEBUG "Qt0SystemInfod.dll" "Qt0SystemInfod.lib" )
    endif()





endif()
